@@ -492,12 +492,31 @@ subset_tidyseurat <- function(.data, .column) {
     .column <- enquo(.column)
 
     # Check if column present
-    if (quo_names(.column) %in% colnames(.data) %>% all %>% `!`)
-        stop("nanny says: some of the .column specified",
+    if (.data |> select(!!.column) |> colnames() %in% colnames(.data) %>% all %>% `!`)
+        stop("tidyseurat says: some of the .column specified",
             " do not exist in the input data frame.")
 
+
     .data %>%
     # Selecting the right columns
         select(!!.column, get_specific_annotation_columns(.data, !!.column)) %>%
         distinct()
 }
+
+#' @importFrom Seurat GetAssayData
+#' @importFrom methods is
+GetAssayData_robust = function(seurat_assay, layer = NULL){
+  
+  if(
+    seurat_assay |> is("Assay5") & 
+    seurat_assay |> ncol() == 1
+  ){
+    m = seurat_assay@layers[[layer]] |> as.matrix()
+    rownames(m) = rownames(seurat_assay)
+    colnames(m) = colnames(seurat_assay)
+    m
+  }
+    
+  else 
+    GetAssayData(seurat_assay, layer=layer)
+}
